#!/usr/bin/perl -w
#
# layout.pl
#
# Common routines for building the output tables for WebFront.
# Note that the caller must do a 'use CGI' before importing.
#
# Copyright 1998 Corel Computer Corporation
#
# This is open-source software (see www.opensource.org).  Open Source(R)
# is a Registered Certification Mark of Software in the Public Interest.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as 
# published by the Free Software Foundation; either version 1,
# or, (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; see the file COPYING.  If not, write to the
# Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.


use strict;

# Navigation bars are defined here:

my @navbar1 = (

  # image link helpname selected_image highligh_image

  [ qw( topleft http://www.corelcomputer.com/support/ws/index.html uhome topleft topleftsel)],
  [ qw( lowertopspace nil nil)],
  [ qw( butususup userlist uusers butususdn butusushi)],
  [ qw( butusgrup grouplist ugroups butusgrdn butusgrhi)],
  [ qw( butusacup account/main uaccount butusacdn butusachi)],
  [ qw( sidesquare nil nil )],
  [ qw( butusadup admin/userlist uadmin butusaddn butusadhi)],
  [ qw( bottomcorner nil nil)]
);

my @navbar2 = (

  # image link helpname selected_image highligh_image

  [ qw( topleft http://www.corelcomputer.com/support/ws/index.html ahome topleft topleftsel)],
  [ qw( lowertopspace nil nil)],
  [ qw( butadusup admin/userlist ausers butadusdn butadushi)],
  [ qw( butadgrup admin/grouplist agroups butadgrdn butadgrhi)],
  [ qw( butadssup admin/stats astatistics butadssdn butadsshi)],
#  [ qw( butadspup admin/param aparameters butadspdn butadsphi)],
  [ qw( sidesquare nil nil)],
  [ qw( butadmpup index amain butadmpdn butadmphi)],
  [ qw( bottomcorner nil nil)]
);

my %navbar = (
  'user'=>\@navbar1,
  'admin'=>\@navbar2
);

# Lookup tables for the titlebar

my %titlebar = (
  'user' => [ qw( congrats userlist grouplist accprofile moduser) ],
  'admin' => [ qw( adminpage userlist grouplist systats moduser modgroup) ],
);

# Suboptions navigation bar

my @subbar1 = (
  [ qw( settings account/main usettings)],
  [ qw( webcreate account/creator uwebcreate)],
#  [ qw( usestats account/usage ustats)],
);

my @subbar2 = (
  [ qw( newuser admin/umain anewuser )]
);

my @subbar3 = (
  [ qw( newgroup admin/gmain anewgroup)]
);

my %subbar = (
  'user2' => \@subbar1,
  'admin0' => \@subbar2,
  'admin1' => \@subbar3,
);

# Functions for generating java-help tags

sub help {
  # Pass the help-file-key as only argument
  my $helpcgi = "/cgi-bin/corel/help.cgi";
  return ('onmouseover',"showhelp('$helpcgi?what=$_[0]')",
          'onmouseout', "showhelp('$helpcgi?what=empty')");
}

sub imghelp {
  # Args: help-file-key, regular image, highlight image
  my $helpcgi = "/cgi-bin/corel/help.cgi";
  return ('onmouseover',"showhelp('$helpcgi?what=$_[0]'),".
            "select('$_[0]','/images/$_[2].jpg')",
          'onmouseout', "showhelp('$helpcgi?what=empty'),".
            "deselect('$_[0]','/images/$_[1].jpg')");
}

#
# The start_webfront() and end_webfront() routines are intended to
# be used as wrappers around individual modules, so that the output
# format will have the same overall format.
#

# Call this function to build the navigation bar:

sub start_webfront {

  # This function takes the following arguments:

  my $title = $_[0];		# String to be used as page title
  my $page = $_[1] || 'user';	# Either 'user' or 'admin'
  my $select = $_[2];		# Currently selected menu button, or -1
  my $subopt = $_[3];		# Suboption menu selection (snake trail)


  # Construct the navigation bar

  my $navbar;
  my @navbar = @{$navbar{$page}};
 
  for (my $i=0; $i<=$#navbar; $i++) {
    my @line = @{$navbar[$i]};
    if ($i >= 2 and $i < 5 and $i == $select+2) { 
      $line[0] = $line[3]; $line[4] = $line[3];
    }
    my $item = CGI::img({-src=>"/images/$page/$line[0].jpg",-border=>'0',
                         -name=>"$line[2]"});

    # Add a hyperlink
    if ($line[1] ne 'nil') { 
      if ($i == 0) {
        # First item gets a TARGET=_top tag added, and no .CGI ext
        $item = CGI::a({-href=>"$line[1]",-target=>'_top',
          imghelp($line[2],"$page/$line[0]","$page/$line[4]")},$item);
      } else {
        $item = CGI::a({-href=>"/cgi-bin/corel/$line[1].cgi",
          imghelp($line[2],"$page/$line[0]","$page/$line[4]")},$item);
      }
    }
    $navbar .= "   $item<BR>\n";
  };


  # Set up the snake trail
  
  my $snake = qq(<IMG SRC="/images/$page/tallmid.jpg"><BR>);
  if ($subopt >= 0) {
    $snake = qq(<IMG SRC="/images/$page/tallmidsub.jpg"><BR>);
    my $loop = $select;
    while ($loop-- > 0) {
      $snake .= qq(<IMG SRC="/images/$page/subspacer.jpg"><BR>);
    }
    $snake .= qq(<IMG SRC="/images/$page/subendbot.jpg"><BR>);
  }


  # Set up the upper half of the main area

  # Turn on highlighting of active sub-menu
  ${${$subbar{"$page$select"}}[$subopt]}[0] .= "active"
  if $select >= 0 and $subopt >= 0;

#  my $main = qq(<IMG SRC="/images/$page/ban_userlist.jpg"><BR>);

  my $titleimg = $titlebar{$page}[$select+1];
  my $main = CGI::img({-src=>"/images/$page/ban_$titleimg.jpg"})."<BR>";
 
  $main .=
CGI::table({-border=>'0',-cellspacing=>'0',-cellpadding=>'0',valign=>'top'},
            CGI::Tr({-align=>'left',-valign=>'top'},
             (($subopt >= 0) ?
                 CGI::td(qq(<IMG SRC="/images/$page/smallmidsub.jpg">)).
                 join "\n", 
                   map CGI::td(CGI::a({-href=>"/cgi-bin/corel/$$_[1].cgi",
                       help($$_[2])},
                     CGI::img({-src=>"/images/$page/$$_[0].jpg",-border=>'0'}))),
                     @{$subbar{"$page$select"}}
               : CGI::td(qq(<IMG SRC="/images/$page/smallmid.jpg">))).
  	     (($subopt >= 0) ? 
  	         CGI::td(qq(<IMG SRC="/images/$page/subendtop.jpg">))
  	       : "")));


  # Here is our javascript (yucch)
  my $jscript = <<END;
   function showhelp(argument) { if (window != parent) 
    { var target = parent.help.location.replace(argument); } }
   function select(img_name,img_src) { document[img_name].src = img_src; }
   function deselect(img_name,img_src) { document[img_name].src = img_src; }
END

 # Collect results are return them to caller:

  return CGI::header(-expires=>'-1d') . 
         CGI::start_html(-bgcolor=>'white',-title=>$title,-text=>'black',
                         'link'=>'blue',-vlink=>'navy',-script=>$jscript) .
         '<TABLE ALIGN="CENTER" WIDTH="780" BORDER="0"' .
         ' CELLSPACING="0" CELLPADDING="0">' . "\n" .
         ' <TR VALIGN="TOP">' . "\n" .
         "  <TD WIDTH=122>\n$navbar  </TD>\n" .
         "  <TD WIDTH=39>\n$snake  </TD>\n" .
         "  <TD WIDTH=619>\n$main";
}


# Call this function to tidy up afterwards.

sub end_webfront() {
 return "  </TD></TR></TABLE>\n". CGI::end_html();
}


# Leave a non-zero exit status:
1;
